@@ -1,16 +1,15 @@
-/*
- Time formatting tests
+// Formatting library for C++ - time formatting tests
+//
+// Copyright (c) 2012 - present, Victor Zverovich
+// All rights reserved.
+//
+// For the license information refer to format.h.
 
- Copyright (c) 2012 - 2016, Victor Zverovich
- All rights reserved.
-
- For the license information refer to format.h.
- */
 #ifdef WIN32
 #define _CRT_SECURE_NO_WARNINGS
 #endif
 
-#include "gmock/gmock.h"
+#include "gmock.h"
 #include "fmt/time.h"
 
 TEST(TimeTest, Format) {
@@ -27,7 +26,7 @@ TEST(TimeTest, GrowBuffer) {
   for (int i = 0; i < 30; ++i)
     s += "%c";
   s += "}\n";
-  std::time_t t = std::time(0);
+  std::time_t t = std::time(nullptr);
   fmt::format(s, *std::localtime(&t));
 }
 
@@ -35,7 +34,7 @@ TEST(TimeTest, EmptyResult) {
   EXPECT_EQ("", fmt::format("{}", std::tm()));
 }
 
-bool EqualTime(const std::tm &lhs, const std::tm &rhs) {
+static bool EqualTime(const std::tm &lhs, const std::tm &rhs) {
   return lhs.tm_sec == rhs.tm_sec &&
          lhs.tm_min == rhs.tm_min &&
          lhs.tm_hour == rhs.tm_hour &&
@@ -48,13 +47,13 @@ bool EqualTime(const std::tm &lhs, const std::tm &rhs) {
 }
 
 TEST(TimeTest, LocalTime) {
-  std::time_t t = std::time(0);
+  std::time_t t = std::time(nullptr);
   std::tm tm = *std::localtime(&t);
   EXPECT_TRUE(EqualTime(tm, fmt::localtime(t)));
 }
 
 TEST(TimeTest, GMTime) {
-  std::time_t t = std::time(0);
+  std::time_t t = std::time(nullptr);
   std::tm tm = *std::gmtime(&t);
   EXPECT_TRUE(EqualTime(tm, fmt::gmtime(t)));
 }
